<div class="ds ds-comment-list" style="display: none;">
    {% for comment in comments %}
        {% include "disqus_sync/comment.html" %}
    {% endfor %}
</div>

<div id="disqus_thread"></div>
    <script type="text/javascript">
        var disqus_shortname = '{{ conf.FORUM }}';

        /* * * DON'T EDIT BELOW THIS LINE * * */
        (function() {
            var dsq = document.createElement('script'); dsq.type = 'text/javascript'; dsq.async = true;
            dsq.src = '//' + disqus_shortname + '.disqus.com/embed.js';
            (document.getElementsByTagName('head')[0] || document.getElementsByTagName('body')[0]).appendChild(dsq);
        })();
    </script>
    <noscript>Please enable JavaScript to view the <a href="http://disqus.com/?ref_noscript">comments powered by Disqus.</a></noscript>
</div>

